@@ -4,10 +4,10 @@ from XgridFoundation import *
 
 class TestXGFileDownload (TestCase):
     def testMethods(self):
-        self.failUnlessArgIsBOOL(XGFileDownload.setDestination_allowOverwrite_, 1)
+        self.assertArgIsBOOL(XGFileDownload.setDestination_allowOverwrite_, 1)
 
     def testProtocols(self):
-        self.failUnlessIsInstance(protocols.XGFileDownloadDelegate, objc.informal_protocol)
+        self.assertIsInstance(protocols.XGFileDownloadDelegate, objc.informal_protocol)
 
 
 if __name__ == "__main__":
